Minnesota Court of Appeals Unpublished and Order Opinions

Minnesota Court of Appeals
April - June 2014
Unpublished and Order Opinions

Listed in reverse chronological order.

#### June 30, 2014

- A13-703, State of Minnesota, Respondent, vs. John Stephen Woodward, Appellant.
- A13-713, State of Minnesota, Respondent, vs. Terrell Darnell Moffett, Appellant.
- A13-866, State of Minnesota, Respondent, vs. Thomas Lee Griffin, Appellant.
- A13-1001, State of Minnesota, Respondent, vs. Kevin Lee Black, Appellant.
- A13-1059, State of Minnesota, Respondent, vs. Arthur Bruce Clark, Appellant.
- A13-1142, State of Minnesota, Respondent, vs. Lee David Riutzel, Appellant.
- A13-1324, State of Minnesota, Respondent, vs. Dean Nathanial Benedict, Appellant.
- A13-1401, Theresa White, Respondent, vs. Catheter Robotics, Inc., Appellant.
- A13-1425, State of Minnesota, Respondent, vs. Robert Tauqueer Johnson, Appellant.
- A13-1606, State of Minnesota, Respondent, vs. Shawn Wardell Embry, Appellant.
- A13-1633, RELCO, LLC, Appellant, vs. A. Kent Keller, et al., Respondents, Roger Allan Ochsner, et al., Defendants.
- A13-1777, Michael R. Lange, et al., Appellants, vs. Mark A. Litman, et al., Respondents.
- A13-1822, Kimberly A. Thomas, Relator, vs. US Bank National Association, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1847, RKL Landholding, LLC, Relator, vs. Ramsey County Board of Commissioners, Respondent.
- A13-1848, Ronald Michael Riegert, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1911, Shoppes at Prairie Run Property Group, LLC, Appellant, vs. Kathy Draeger, et al., d/b/a D's Family Pizza, LLC, Respondents.
- A13-1916, In re the Marriage of: Maria Toso, petitioner, Respondent, vs. Victor Olaf Toso, Appellant.
- A13-1939, Brian William Miller, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2048, In the Matter of the Civil Commitment of: Adam Leroy Meyer, and In the Matter of the Civil Commitment of: Gary Peter Scott.
- A13-2057, State of Minnesota, Respondent, vs. Keith Ward Hohlen, Appellant.
- A13-2060, Shane Larry Minnick, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-2066, Ann Westre-Nelson, Relator, vs. Coborn�s Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-2102, Maple Bank, Appellant, vs. St. Louis Park Public School District No. 283, et al., Defendants and Third Party Plaintiffs, Respondents, vs. Rea Properties, LLC, et al., Third Party Defendants.
- A13-2119, Daniel S. Carlson, et al., Appellants, vs. Michelle Figueroa, Respondent, Kelly Carlson, Respondent.
- A13-2137, Eldo Abrahamson, Relator, vs. Minneapolis Oxygen Comp-Joint Acct., Respondent, Department of Employment and Economic Development, Respondent.
- A13-2161, Patricia L. Peterson, et al., Appellants, vs. Northern Gaul Properties, Inc., et al., Respondents.
- A13-2183, In the Matter of the Civil Commitment of: Wayne Carl Nicolaison.
- A13-2226, Timothy Leroy Carlson, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2366, Cory David Williams, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A14-118, In the Matter of the Civil Commitment of: Hugh Charles Rogers.
- A13-1838, James Mudrick, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.(June 2014, Reversed. Order opinion.)
- A14-2, In re the Marriage of: Karen Maureen Rye, petitioner, Respondent, vs. Jay Francis Cook, Appellant. (June 2014, Reversed. Order opinion.)

#### June 23, 2014

- A12-2064, State of Minnesota, Respondent, vs. Robert Brooks Hoel, Appellant.
- A13-678, State of Minnesota, Respondent, vs. Aka Lawrence Fualefeh, Appellant.
- A13-808, State of Minnesota, Respondent, vs. Brian Thomas Whaley, Appellant.
- A13-962, State of Minnesota, Respondent, vs. Maureen Ann O�Brien, Appellant.
- A13-1046, State of Minnesota, Respondent, vs. Holyfield Ikeyan James, Appellant.
- A13-1086, State of Minnesota, Respondent, vs. Wendy Marie Cloutier, Appellant.
- A13-1124, State of Minnesota, Respondent, vs. Joshua Joe Quast, Appellant.
- A13-1174, State of Minnesota, Respondent, vs. Aron Montrell Evans, Appellant.
- A13-1247, State of Minnesota, Respondent, vs. Rosvan Barnes, Appellant.
- A13-1249, State of Minnesota, Respondent, vs. Donald Joseph Schlichting, Appellant.
- A13-1322, State of Minnesota, Respondent, vs. Rory Allen Koch, Appellant.
- A13-1326, Paul Jonathan Aubart, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-1513, State of Minnesota, Respondent, vs. Kong Meng Vang, Appellant.
- A13-1516, State of Minnesota, Respondent, vs. Michael Sean Dickenson, Appellant.
- A13-1531, Lawrence Jeffrey Erickson, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1683, State of Minnesota, Respondent, vs. Ryan Scott Brown, Appellant.
- A13-1739, Willie Harris, Relator, vs. Summit Early Learning Center, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1745, Stephen R. Colburn, Relator, vs. Top Tool Company, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1775, State of Minnesota, Respondent, vs. Douglas Paul Pierce, Appellant.
- A13-1825, State of Minnesota, Respondent, vs. Nicholas David McPherson, Appellant.
- A13-1892, In re the Marriage of: Elizabeth Mary Shults, petitioner, Respondent, vs. Fount LeRon Shults, Appellant.
- A13-1896, Jeffrey Ross Lindquist, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-1923, Chad Robert Bauer, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-1934, State of Minnesota, Appellant, vs. Cesar Delagarza, Respondent.
- A13-1987, Gary Modlin, Appellant, vs. Pope County Soil and Water, Respondent.
- A13-2074, Jacob Joseph Vaith, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2087, Trivedi LLC, et al., Appellants, vs. Dennis Lang, Respondent.
- A13-2098, Terrance J. Friend, petitioner, Appellant, vs. Lucinda Jesson, Commissioner of Human Services, Respondent
- A13-2216, Derek Kulla, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-2246, William Harvey Elyea, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2271, In the Matter of the Civil Commitment of: Peter Allan, a/k/a Peter Allan George, Peter Slaton, Peter Allan Kyute.
- A14-13, In the Matter of the Civil Commitment of: Eric John Eischens.
- A14-155, Abdel M. El Rashidi, Relator, vs. Building Materials Manufacturing Company (Corp.), Respondent, Department of Employment and Economic Development, Respondent.
- A14-231, In re the Matter of: Amy Sue Hagen, petitioner, Appellant, vs. Daniel John Schirmers, Respondent.

#### June 16, 2014

- A13-611, In re the Marriage of: Michon A. Ross, petitioner, Respondent, vs. Kevin G. Ross, Appellant.
- A13-854,State of Minnesota, Respondent, vs. Travis Kyle Mayer, Appellant.
- A13-979, State of Minnesota, Respondent, vs. Jason Michael Larson, Appellant.
- A13-998, State of Minnesota, Respondent, vs. Kenneth Audie Leason, Appellant.
- A13-1042, State of Minnesota, Respondent, vs. Robert Mark Dengler, Appellant.
- A13-1083, State of Minnesota, Respondent, vs. Thomas Dwayne Brown, Appellant.
- A13-1096, State of Minnesota, Respondent, vs. Warren Patrick Banks, Jr., Appellant.
- A13-1248, State of Minnesota, Respondent, vs. James Ervin Roark, Appellant.
- A13-1487, State of Minnesota, Respondent, vs. Timothy George Clark, Appellant.
- A13-1612, Sandra L. Balbach, Appellant, vs. Irving Township Board, Respondent.
- A13-1674, Liban Mohamed, Relator, vs. Jennie-O Turkey Store, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1762, Shatante Boyd, Respondent, vs. Atterro, Inc., Relator, Department of Employment and Economic Development, Respondent.
- A13-1832, Kolo Howard, Relator, vs. Select Senior Living, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1899, Todd Larry Tennin, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1924, In the Matter of the Welfare of: M. J. B., Juvenile.
- A13-1946, Joan Wienbar, Appellant, vs. Westridge Mall Limited Partnership, Respondent.
- A13-1978, State of Minnesota, Respondent, vs. Obuey Abella Thowl, Appellant.
- A13-2195, In the Matter of the Civil Commitment of: Ming Sen Shiue.
- A13-2338, William Joseph Eggert, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A14-120, James Freeman, Appellant, vs. Lucinda Jesson, Commissioner of Human Services, Respondent.
- A14-629, State of Minnesota, Respondent, vs. Kevin Michael Smith, Appellant.
- A13-2069, Kevin Swanson, Relator, vs. Smead Manufacturing Company Minnesota, Respondent, Department of Employment and Economic Development, Respondent.(June 2014, Affirmed. Order opinion.)
- A13-2101, State of Minnesota, Respondent, vs. E. M. L., Appellant. (June 2014, Reversed and remanded. Order opinion.)

#### June 9, 2014

- A13-674, State of Minnesota, Respondent, vs. Michael Patrick Keefe, Appellant.
- A13-879, State of Minnesota, Respondent, vs. Michael Allen Andersen, Appellant.
- A13-930, State of Minnesota, Respondent, vs. Donavan Dexter Boone, Appellant.
- A13-952, State of Minnesota, Respondent, vs. Alex Cortez Benson, Appellant.
- A13-988, State of Minnesota, Respondent, vs. Christopher Robert Krych, Appellant.
- A13-1183, State of Minnesota, Respondent, vs. Levi Braziel, Jr., Appellant.
- A13-1246, State of Minnesota, Respondent, vs. Charles D. Soderberg, Appellant.
- A13-1398, State of Minnesota, Respondent, vs. Raven Bianca Gant, Appellant.
- A13-1424, State of Minnesota, Respondent, vs. Sabin Mitchell Myhra, Appellant.
- A13-1437, Joni Quam, Appellant, vs. St. Francis Health Services of Morris, et al., Respondents.
- A13-1478, In the Matter of: Candace Marie Hensley, individually and obo Caden Robert Hall, petitioner, Respondent, vs. Derek Wyatt Hall, Appellant.
- A13-1590, State of Minnesota, Appellant, vs. Benjamin Curtiss Ornquist, Respondent.
- A13-1609, Evonne Thode, Relator, vs. Public Employees Retirement Association, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1692, State of Minnesota, Appellant, vs. Susan Marie Quiram, Respondent.
- A13-1737, Joshua C. Steel, Relator, vs. Department of Employment and Economic Development, Respondent.
- A13-1767, Joseph Robert Bjornoos, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-1797, C. H. Robinson Worldwide, Inc., Respondent, vs. XPO Logistics, Inc., et al., Defendants, Louis J. Amo, Jr., et al., Appellants, Robert A. Martin, Co-Appellant.
- A13-1810, Brian Stuckey, Relator, vs. North Oaks Holiday and Auto Service, Inc., Respondent, Department of Employment and Economic Development, Respondent
- A13-1986, Sandra Haub, Relator, vs. Department of Employment and Economic Development, Respondent.
- A13-1998, Samuel Thomas Sonsalla, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2020, Benjamin Robert DeMaris, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent
- A13-2157, James J. Shorter, et al., Plaintiffs, vs. Equity Bank, Respondent, James I. Vermilya, et al., Appellants.
- A13-2202, In the Matter of the Welfare of: A. A. C.-F., Child.
- A13-2241, Shawn David Greene, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-2252, State of Minnesota, Appellant, vs. Gary James Johnson, Respondent.
- A13-2351, In the Matter of the Welfare of: O. C. W., Child.
- A13-2409, State of Minnesota, Respondent, vs. Anthony Michael Bishop, Appellant.
- A14-18, In the Matter of the Welfare of the Child of: M. B. B., Parent.
- A13-1748, State of Minnesota, Respondent, vs. M.S.M.K., Appellant.(June 2014, Affirmed. Order opinion.)
- A13-1908, State of Minnesota, Appellant, vs. Dominick Jon Ross, Respondent, .(June 2014, Reversed. Order opinion.)

#### June 2, 2014

- A12-1655, State of Minnesota, Respondent, vs. Deonandre Tyree Pendelton, Appellant.
- A13-736, State of Minnesota, Respondent, vs. Cohen James Curfman, Appellant.
- A13-957, Patrick Lawrence Zabinski, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1045, State of Minnesota, Respondent, vs. Araya Woldeselassie, Appellant.
- A13-1061, Nott Company, Appellant, vs. Dean Eberhardt, et al., Respondents.
- A13-1081, State of Minnesota,Respondent, vs. Angel Hernandez-Espinoza, Appellant.
- A13-1100, State of Minnesota, Respondent, vs. Gerald Gerard Beverly, Appellant.
- A13-1104, Mahmood Khan, Relator, vs. City of Minneapolis, Respondent.
- A13-1177, State of Minnesota, Respondent, vs. Rogelio Santillana, Jr., Appellant.
- A13-1194, State of Minnesota, Respondent, vs. Reginald Bruce Long.
- A13-1334, County of Winona, petitioner, Respondent, vs. Kelley McCullough O'Neill, et al., Appellants.
- A13-1503, State of Minnesota, Respondent, vs. Dwight David Patterson, Appellant.
- A13-1505, Stacey J. Jorgenson, Relator, vs. Recover Health Services LLC, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1507, Daniel Ray Hernandez, Relator, vs. Mydatt Services, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1527, Benjamin C. Van Sant, Relator, vs. Modernistic, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1785, Richard Eugene Baumeister, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1805, Christina Ruscher, Relator, vs. A�viands LLC, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1885, Christopher James Waldorf, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-1926, Erin Anthony Ryan, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2000, Tylor John Neuman, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2076, Jacob Karl Rask, petitioner, Appellant, vs. State of Minnesota, Department of Human Services, et al., Respondents.
- A13-2158, First Resource Bank, Respondent, vs. DJ Land Development, LLC, et al., Appellants.
- A13-2266, Wilmington Trust Company, as Trustee, Respondent, vs. Kenneth F. Northwick, et al., Appellants.
- A13-2339, In the Matter of the Welfare of the Children of: J. L. J. T. and B. L. H., Parents.

#### May 27, 2014

- A12-1647, State of Minnesota, Respondent, vs. Jon Stephen Erickson, Appellant.
- A13-53, State of Minnesota, Respondent, vs. Jeremy John Donner, Appellant.
- A13-205, State of Minnesota, Respondent, vs. Bryan Dale Purdom, Appellant.
- A13-373, State of Minnesota, Respondent, vs. Paul Jacob Bohn Salmon, Appellant.
- A13-595, State of Minnesota, Respondent, vs. Gary Jerrod Phillips, Appellant.
- A13-675, State of Minnesota, Respondent, vs. Maurice Lennell Weatherspoon, Appellant.
- A13-716, State of Minnesota, Respondent, vs. Antwon Demetrius Robinson, Appellant.
- A13-765, State of Minnesota, Respondent, vs. James Charles Morgan, Appellant.
- A13-990, State of Minnesota, Respondent, vs. Bernard Neal, Appellant.
- A13-1090, State of Minnesota, Respondent, vs. Kevin Jackson Brown, Appellant.
- A13-1127, State of Minnesota, Respondent, vs. Santana Martinez Valdez, Appellant.
- A13-1310, State of Minnesota, Respondent, vs. Joseph Ntambwe Mukokolo, Appellant.
- A13-1354, Douglas A. Peterson, Relator, vs. U.S. Federal Employees, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1452, Kathy Clark, Relator, vs. House of Charity, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1454, Robin Berry, Relator, vs. City of Minneapolis Public Housing, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1554, John Green, Appellant, vs. Greg Kellen, Respondent.
- A13-1671, Julie A. Bennett, Relator, vs. Castle Kitchen Corporation, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1693, State of Minnesota, Appellant, vs. Michael John Selle, Respondent.
- A13-1696, State of Minnesota, Respondent, vs. Stephanie Colleen Miller, Appellant.
- A13-1755, Dakota County, Respondent, vs. N. J. H. D., Appellant.
- A13-1770, State of Minnesota, Respondent, vs. Craig Kevin Lee, Appellant.
- A13-1874, Jeremy Thomsen, Relator, vs. Metes & Bounds Management Company (Corp.), Respondent, Department of Employment and Economic Development, Respondent.
- A13-1902, Jonathon Joel Bathen, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1994, John J. Clemons, Appellant, vs. MRCI WorkSource, Respondent.
- A13-1861, Logan Mudgett, Appellant, vs. Wade Setter, Respondent.(May 2014, Reversed. Order opinion.)
- A13-1938, Ronald Shellito, Relator, vs. Masterson Personnel, Inc., Respondent, Department of Employment and Economic Development, Respondent.(May 2014, Affirmed. Order opinion.)

#### May 19, 2014

- A13-466, State of Minnesota, Respondent, vs. Jamarr Marcelles Elliott, Appellant.
- A13-659, State of Minnesota, Respondent, vs. Kenwood Alan Lacey, Appellant.
- A13-719, Robert L. Foster, Jr., petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-770, State of Minnesota, Respondent, vs. Roland Olando Mawolo, Appellant.
- A13-802, Raven Financial, LLC, Relator, vs. City of St. Paul, Respondent.
- A13-846, State of Minnesota, Respondent, vs. Humberto Chavez, Jr., Appellant.
- A13-980, State of Minnesota, Respondent, vs. Jaimie Lee Mudge, Appellant.
- A13-981, State of Minnesota, Respondent, vs. Larry Darnell Lakes, Appellant.
- A13-1179, State of Minnesota, Respondent, vs. Eric James Rutherford, Appellant.
- A13-1182, State of Minnesota, Respondent, vs. Benjamin Joseph Hill, Appellant.
- A13-1275, Belford William Reitz, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1288, Tamara Nelson, Relator, vs. Donnelly Development, LLC, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1392, Derek Browen, Relator, vs. Thompson Construction of Princeton, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1543, David Phaneuf, et al., Appellants, vs. Bruce Sobotta, individually and as Clearwater Township Commissioner, et al., Respondents, Stephen J. Broughton, et al., Respondents.
- A13-1588, David Randy Sabby, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1643, In the Matter of the Resident Agency License of Northwest Title Agency, Inc.; the Resident Insurance Producer�s License of Wayne B. Holstad; the Notary Commission of Wayne B. Holstad; and Northwest Abstract Company.
- A13-1669, Alan Sargent, Relator, vs. Manny Moe & Jack of California, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1686, Svetlana Schmitz, et al., Appellants, Liberty Mutual Insurance Company, intervenor, Respondent, vs. William Joseph Rowekamp, Respondent, State of Minnesota, Respondent.
- A13-1757, Kenneth Richard Hunt, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1870, Shantha Jayapathy, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1914, Foos Mohamed Aden, Appellant, vs. Allstate Indemnity Company, Respondent.
- A13-1982, Christie Arnold Matheson, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant.
- A13-2306, In the Matter of the Welfare of the Child of: A. B. and D. B., Parents.
- A13-1274, State of Minnesota, Respondent, vs. Jeffrey Travis Elledge, Appellant.(May 2014, Reversed and remanded. Order opinion.)

  #### May 14, 2014

- A12-2345, State of Minnesota, Respondent, vs. Donald Allen Ellis, Appellant.
- A13-418, State of Minnesota, Respondent, vs. Douglas Carl Manney, Appellant.
- A13-608, State of Minnesota, Respondent, vs. Joseph Gassoway, Appellant.
- A13-750, State of Minnesota, Respondent, vs. Misty Marie Littlewolf, Appellant.
- A13-763, State of Minnesota, Respondent, vs. Joseph Michael Malmo, Appellant.
- A13-801, State of Minnesota, Respondent, vs. Andrew Wayne Clarke, Appellant.
- A13-825, In re the Marriage of: Heather Ann McGraw, petitioner, Appellant, vs. Timothy Brendan McGraw, Respondent.
- A13-853, State of Minnesota, Respondent, vs. Luke Brandon Scott, Appellant.
- A13-972,Builders Development & Finance, Inc., Respondent, Lake Ann, LLC, Respondent, vs. Vern Reynolds Construction Company, Inc., et al., Appellants.
- A13-987, State of Minnesota, Respondent, vs. Lancintino Antwon Flemino, Appellant.
- A13-1033, State of Minnesota, Respondent, vs. Marcus Darnell Luckett, Appellant.
- A13-1070, State of Minnesota, Respondent, vs. Michael Benjamin Goodman, Appellant.
- A13-1352, In re the Marriage of: Kathleen Denice Luethmers, petitioner, Respondent, vs. Alan James Luethmers, Appellant.
- A13-1400, William Edwin Lehman, Jr., petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1523, State of Minnesota, Appellant, vs. Carl James White, Jr., Respondent.
- A13-1528, Central Specialties, Inc., Appellant, vs. Todd County, Minnesota, Respondent.
- A13-1691, State of Minnesota, Appellant, vs. Jonathan Lee Church, Respondent.
- A13-1734, Yelena Kurdyumova, Appellant (A13-1734), Sergey Porada, Appellant (A13-1735), vs. Mitchell A. Robinson, Respondent.
- A13-1789, State of Minnesota, Respondent, vs. Rip Wayne Rust, Appellant.
- A13-1808, Youa C. Kue, Relator, vs. Tyco Healthcare Group LP, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1833, Cindy Tomczak, Respondent, vs. Gearhart, Melanie J., Relator, Department of Employment and Economic Development, Respondent
- A13-1890, Brad Ronald Stevens, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1907, Edisson Daniel Lema, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-2017, State of Minnesota, Appellant, vs. Abdihakin Ali Farah, Respondent.
- A13-2077, In re the Marriage of: Shandin Cowle Moyne, petitioner, Respondent, vs. Fabrice Jacques-Pierre Moyne, Appellant.
- A13-2114, In the Matter of the Welfare of: J. O., Child.
- A14-36, State of Minnesota, Respondent, vs. Elton Lamar Brown, III, Appellant.
- A14-88, City of Mountain Lake, Respondent, vs. Kenneth Yoder, et al., Appellants.
- A13-1512, State of Minnesota, Respondent, vs. Jeffrey Holman, Appellant.(May 2014, Affirmed. Order opinion.)

#### May 5, 2014

- A12-2245, In re the Marriage of: Laura Helen Shores, petitioner, Respondent, vs. Kevin Richard Shores, Appellant.
- A13-556, State of Minnesota, Respondent, vs. Cohen James Curfman, Appellant.
- A13-596, State of Minnesota, Respondent, vs. Natosha Marie Dyre, Appellant.
- A13-708, State of Minnesota, Respondent, vs. Carl Augustus Brown, Appellant.
- A13-881, State of Minnesota, Respondent, vs. James Howard Klein, Appellant.
- A13-908, In re the Custody of I. J. H. and M. J. S.-H. Kidane Sante Shulbe, petitioner, Appellant, vs. Ashley Rose Henke, Respondent.
- A13-912, State of Minnesota, Respondent, vs. Anthony David Gurneau, Appellant.
- A13-935, State of Minnesota, Respondent, vs. Sunday Htoo, Appellant.
- A13-986, Denise Walker and Brian Walker, on behalf of themselves and other Minnesota taxpayers, Appellants, vs. Lucinda Jesson, in her official capacity as Commissioner, Minnesota Department of Human Services, Respondent, and Pro-Choice Resources, Applicant of Intervention Below.
- A13-1149, Michele Proefrock, Relator, vs. Brighter Day Residence, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1256, David Baldridge, Relator, vs. Department of Employment and Economic Development, Respondent.
- A13-1414, In re the Marriage of: Karen Maureen Rye, petitioner, Respondent, vs. Jay Francis Cook, Appellant.
- A13-1417, Wells Fargo Bank, N.A., Respondent, vs. Tony Badrawi, Defendant, Mary J. Badrawi, Appellant.
- A13-1428, Cicero Deshawn Taylor, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1506, Michael W. Fridgen, Relator, vs. University of Minnesota, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1530, Scott W. Wildung and Susan K. Wildung, Appellants, vs. The Bank of New York Mellon as Trustee for RBSGC Mortgage Loan Trust Mortgage Pass-Through Certificates, Series 2005-RPI, Respondent.
- A13-1547, State of Minnesota, Appellant, vs. Troy Edward Porter, Respondent.
- A13-1575, Robert W. Garves, Relator, vs. VFW - Coon Rapids - Post 9625 of U.S., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1602, State of Minnesota, Appellant, vs. Mark Harlan Olson, Respondent.
- A13-1619, State of Minnesota, Respondent, vs. Anthony Mitchell Spry, Appellant.
- A13-1695, Derek Leanderther Grant, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1701, In re the Marriage of: Nader Charles Kazeminy, petitioner, Respondent, vs. Jibil Eftekhar Kazeminy, Appellant.
- A13-1714, State of Minnesota, Respondent, vs. Erik Dupree Solorio, Appellant.
- A13-1717, Sekou Bamba, Appellant, vs. Minnesota Department of Human Services, et al., Respondents.
- A13-1753, Trinidad Perez-Carrino, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1867, Brenda Lee Miller, petitioner, Appellant, vs. Mitchel Lee Miller, Respondent, County of Carver, intervenor, Respondent.
- A13-1921, Dennis Raymond Christian, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-2146, In the Matter of the Welfare of the Children of: T. L. W., H. M. M., D. F. M., A. P. and J. L. S., Parents.
- A13-2260, State of Minnesota, Respondent, vs. Kiunte Jaishun McCoy, Appellant..

#### April 28, 2014

- A13-313, Alex Jerome, et al., Relators, vs. City of St. Paul, Respondent.
- A13-502, State of Minnesota, Respondent, vs. Alfredo Jesse Rosillo, Appellant.
- A13-504, State of Minnesota, Respondent, vs. Alfredo Jesse Rosillo, Appellant.
- A13-576, State of Minnesota, Respondent, vs. Matthew Roy Nelson, Appellant.
- A13-694, Surgical Principals, Inc., Appellant, vs. Minnesota Medical Development, Inc., Respondent.
- A13-726, Chad Michael Webb, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-791, State of Minnesota, Respondent, vs. Gabriel Robert Kimbrough, Appellant.
- A13-803, State of Minnesota, Respondent, vs. Tane Alexander Finley, Appellant.
- A13-817, State of Minnesota, Respondent, vs. Clinton Lee Strother, Appellant.
- A13-909, Loren Stoll, Respondent, vs. Brambilla�s, Inc., Relator, Department of Employment and Economic Development, Respondent.
- A13-933, State of Minnesota, Respondent, vs. Douglas Michael Trebtoske, Appellant.
- A13-999, State of Minnesota, Respondent, vs. Decarieon Dupra Scurlock, Appellant.
- A13-1099, State of Minnesota, Respondent, vs. Ronald William Beattie, Jr., Appellant.
- A13-1143, State of Minnesota, Respondent, vs. Kia Lee, Appellant.
- A13-1181, State of Minnesota, Respondent, vs. Ismael Hernandez, Appellant.
- A13-1349, In re the Marriage of: Denise Marie Thompson, petitioner, Respondent, vs. Kenneth James Thompson, Appellant.
- A13-1384, Leanda Muhonen, Appellant, vs. Angela Mosier, et al., Respondents.
- A13-1395, Don Newcome Conley, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1405, Joe Edward McCarroll, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1413, OSEMI, Inc., Appellant, vs. Red Wing Port Authority, Respondent.
- A13-1440, State of Minnesota, Respondent, vs. Scott Andrew Bradley, Appellant.
- A13-1553, In the Matter of the Welfare of the Children of: J. L. P., J. E. P., and C. C., Parents.
- A13-1563, State of Minnesota, Appellant (A13-1563), vs. Stephen Howard King, Respondent and Stephen Howard King, petitioner, Respondent, vs. Commissioner of Public Safety, Appellant (A13-1922). [CORRECTION ORDER]
- A13-1573, David Miller, Relator, vs. South Central College - North Mankato, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1666, Terry Bongard, Respondent, vs. Premium Tax Services, Inc., Appellant.
- A13-1704, Thomas Rosen, Appellant, Susan Weir, Plaintiff, vs. Edina Public Schools-Independent School District #273, Respondent.
- A13-1212, In the Matter of the Civil Commitment of: Curtis Wayne Cotton, Jr., .(April 2014, Affirmed. Order opinion.)
- A13-1502, David Kenneth Christian, petitioner, Appellant, vs. State of Minnesota, Respondent.(April 2014, Affirmed. Order opinion.)

#### April 21, 2014

- A12-1337, State of Minnesota, Respondent, vs. Michael John Husten, Appellant.
- A12-1764, In re the Marriage of: Anthony J. Dempsey, petitioner, Appellant, vs. Dawn L. Earl, Respondent.
- A13-50, State of Minnesota, Respondent, vs. Christopher Lee Manska, Appellant.
- A13-599, State of Minnesota, Respondent, vs. Gregory Allen Shartle, Appellant.
- A13-775, State of Minnesota, Respondent, vs. Juan Raul Cardenas, Appellant.
- A13-784, State of Minnesota, Respondent, vs. Paul James Frederick, Appellant.
- A13-874, State of Minnesota, Respondent, vs. Desean Maurice Carter, Appellant.
- A13-1067, State of Minnesota, Respondent, vs. Jacquet Deon Munn, Appellant.
- A13-1128, State of Minnesota, Respondent, vs. Winfred Howard La�Virgne, Appellant.
- A13-1290, Michael James Thompson, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1327, In re the Matter of: Christine Bwari Omwando, petitioner, Respondent, vs. Samuel Nyaboga, Appellant.
- A13-1331, State of Minnesota, Respondent, vs. Chad Matthew Pulju, Appellant.
- A13-1402, Dr. Vibhu Kapoor, Appellant, vs. Dr. Ellen Brown, et al., Respondents.
- A13-1490, City of Shoreview, Respondent, vs. Michael Morse, Appellant.
- A13-1565, Jesus Eduardo Lopez-Silva, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1569, Anovus, L.L.C., Appellant, vs. Wade Ysker, Respondent.
- A13-1672, Danica D. Coons, Relator, vs. Department of Employment and Economic Development, Respondent.
- A13-1733, Michael Sheldon Boswell, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1744, Mark McAllister, Relator, vs. Veolia Es Midwest LLC - Veolia Environmental Services, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1747, Craig Featherly, Relator, vs. Vitran Express, Inc., Respondent, Department of Employment and Economic Development, Respondent.
- A13-1834, Keith Welsh, Appellant, vs. Auto-Owners Insurance Company, Respondent.
- A13-1886, Jessica Jean Strong, Appellant, vs. Joanne Rose Lange, Respondent, State Farm Insurance Company, Respondent.
- A13-1894, In the Matter of the Civil Commitment of: Orlando John Lindgren.
- A13-1897, Perron�s on the Lake, LLC, Appellant, vs. Lakefront Plaza Condominium Association, Respondent.
- A13-1952, State of Minnesota, Appellant, vs. Glenn David Heitzman, Respondent.
- A13-1964, Deutsche Bank National Trust Company as Trustee, Respondent, vs. Frances S. Bland, Appellant, Byron A. Bland, Defendant.
- A13-2003, In the Matter of the Welfare of: D. T. M.-M., a/k/a D. M. M., Child.
- A13-2011, In the Matter of the Welfare of the Child of: J. A. C. and M. J. E.-C., Parents.
- A13-2062, Paul Johnson, Appellant, vs. Mark Dayton, in his official capacity as Governor of Minnesota, et al., Respondents.(April 2014, Affirmed. Order opinion.)

#### April 14, 2014

- A13-251, State of Minnesota, Respondent, vs. Tamarlus Onta Hutto, Appellant.
- A13-386, State of Minnesota, Respondent, vs. Phongsavanh Saengchanthalath, Appellant.
- A13-514, In re the Marriage of: Elizabeth Ann Tagg, petitioner, Respondent, vs. Joel Homer Tagg, Appellant
- A13-662, State of Minnesota, Respondent, vs. Scott Alan Anderson, Appellant.
- A13-776, Lowell D. Berg, et al., Relators, vs. Motokazie, Inc., Respondent, Rice County Board of Commissioners, Respondent.
- A13-899, State of Minnesota, Respondent, vs. Dustin Carl Moen, Appellant.
- A13-907, Charles A. Laliberte, Appellant, vs. State of Minnesota, et al., Respondents, City of Minneapolis, et al., Respondents.
- A13-949, Emily L. Cramble, Respondent, vs. Angela Udell, et al., Appellants.
- A13-1038, State of Minnesota, Respondent, vs. Lesean Anderson, Appellant.
- A13-1094, State of Minnesota, Respondent, vs. Sandra Jean Roulet, Appellant.
- A13-1120, State of Minnesota, Respondent, vs. Antoinette Kay Kuhlmann, Appellant.
- A13-1150, In Re: The H & A Neumann Revocable Trust, dated September 21, 1995.
- A13-1221, Arthur Gacheru Ngacah, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1242, State of Minnesota, Appellant, vs. Nicole Marie Poillon, Respondent.
- A13-1367, In re the Marriage of: Kyle W. Zweifel, petitioner, Respondent, vs. Julie Zweifel, n/k/a Julie A. Mead, Appellant.
- A13-1434, State of Minnesota, Appellant, vs. Scott David Harrom, Respondent.
- A13-1544, John Shelander, Appellant, vs. Johnstech International Corporation, Respondent.
- A13-1675, In re the Marriage of: Christine Lynn Sypnieski, f/k/a Christine Lynn Holtz, petitioner, Appellant, vs. Kevin Douglas Holtz, Respondent.
- A13-1784, State of Minnesota, Respondent, vs. Thomas Mark Beaulieu, Jr., Appellant.
- A13-1788, State of Minnesota, Respondent, vs. Conner Douglas Knutson, Appellant.
- A13-1793, Portfolio Recovery Associates, LLC, Respondent, vs. Diane M. Staeheli, Appellant (A13-1793), Ronald Staeheli, Appellant (A13-1795).
- A13-2036, Joseph Robert Veilleux, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-2049, In the Matter of the Welfare of the Child of: T. B. and O. B., Parents.
- A13-2134, In the Matter of the Welfare of the Children of: A. N. T. and J. W. L., Parents.

#### April 7, 2014

- A12-1500, State of Minnesota, Respondent, vs. Henry Hickman, Appellant.
- A13-433, State of Minnesota, Respondent, vs. Shannon Lee Christianson, Jr., Appellant.
- A13-481, In re the Matter of: Robert James Smith, petitioner, Respondent, vs. Angela Renae Opstad, Appellant.
- A13-540, In re the Marriage of: Lainie Ann Stewart, petitioner, Appellant, vs. James Swedlund Stewart, Respondent.
- A13-672, State of Minnesota, Respondent, vs. Matias Arkiel Jefferson, Appellant.
- A13-681, David Eric Collins, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-730, State of Minnesota, Respondent, vs. Kevin Lee Anthony, Appellant.
- A13-749, State of Minnesota, Respondent, vs. Chad Michael Larson, Appellant.
- A13-783, State of Minnesota, Respondent, vs. Justin John Auck, Appellant.
- A13-800, State of Minnesota, Respondent, vs. Michael NMN Williams, Appellant.
- A13-807, State of Minnesota, Respondent, vs. James Stewart Elliott, Appellant.
- A13-843, Jay Nygard, Appellant, Kendall Nygard, Plaintiff, vs. Penny Rogers, et al., Respondents.
- A13-864, State of Minnesota, Respondent, vs. Jason Michael Paris, Appellant.
- A13-865, State of Minnesota, Respondent, vs. Seth Michael Hambleton, Appellant.
- A13-887, State of Minnesota, Respondent, vs. Ronald Lee, Appellant.
- A13-934, Silvia Lopez, A/K/A Manda Gutierrez, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-953, Brian Scott Poquette, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-955, State of Minnesota, Respondent, vs. Daniel Craig Guthrie, Appellant.
- A13-994, Michael Joseph Harasyn, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1101, Ian Hamman Tulien, petitioner, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-1147, Shelley Ford, Relator, vs. Minnesota State District Courts, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1178, Richard Joseph Akande, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1206, Evon Dickens, Appellant, vs. Lucinda Jesson, Minnesota Commissioner of Human Services, Respondent, Hennepin County Human Services and Public Health Department, Respondent.
- A13-1312, State of Minnesota, Respondent, vs. Katherine Trinka Olson, Appellant.
- A13-1320, In re the Marriage of: Bruce John Prevost, petitioner, Appellant, vs. Darla Kay Prevost, Respondent.
- A13-1344, Discover Bank, Respondent, vs. Crysone C. Lindwall, Appellant.
- A13-1360, Jeffrey Scott Davis, Relator, vs. Kaufman Enterprises, Inc. - Fairview Gardens, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1394, State of Minnesota, Appellant, vs. Arnold Everette Evans, Respondent.
- A13-1421, Thomas Edward Utter, Jr., petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-1570, Private Bank Minnesota, Respondent, vs. Robert M. Anderson, Appellant.
- A13-1760, Kristopher Fingal, Relator, vs. Nexlink Communications LLC, Respondent, Department of Employment and Economic Development, Respondent.
- A13-1872, In the Matter of the Welfare of the Children of: J. R., Parent.
- A13-1984, State of Minnesota, Appellant, vs. Daniel John Seifert, Respondent.
- A13-1988, In the Matter of the Welfare of the Children of: V. R. and A. B., Parents.
- A13-2027, In the Matter of the Welfare of the Child of: D. D. and G. M., Parents.
- A13-954, State of Minnesota, Respondent, vs. Donald Arthur Merrill, Appellant.(April 2014, Affirmed. Order opinion.)
- A13-1438, Naftal M. Ondari, Relator, vs. Bloomington Hotel, Inc.-Hotel Sofitel, Respondent, Department of Employment and Economic Development, Respondent.(April 2014, Affirmed. Order opinion.)
- A13-1732, State of Minnesota, Respondent, vs. Shane Henry Colbath, Appellant.(April 2014, Reversed and remanded. Order opinion.)
- A13-1761, Eric Wallace, Relator, vs. Volt Management Corp., Respondent, Department of Employment and Economic Development, Respondent.(April 2014, Affirmed. Order opinion.)
- A13-2139, Joshua Davis, Relator, vs. Cory Rich, Respondent, Department of Employment and Economic Development.(April 2014, Reversed and remanded. Order opinion.)

MSLL Home Page | | Minnesota Appellate Court System | | Archive Homepage

Phone: (651) 296-2775; Fax: (651) 296-6740

Please send any comments or suggestions to the webweaver.

Last update: June 30, 2014